# kmeanstf

tensorflow-based implementations of the following algorithms:

* k-means with random initialization (Lloyd, 1982)
* k-means++ (Arthur and Vassilvitskii, 2006)
* tunnel k-means (Fritzke, to appear)

Documentation: https://kmeanstf.readthedocs.io/en/latest/

[logo]: https://raw.githubusercontent.com/gittar/kmeanstf/master/img/million_100.png "k-means++ example"

Example of tunnel k-means at work:
<br>
<img src="https://raw.githubusercontent.com/gittar/kmeanstf/master/docs/source/img/tkmeans1.png" width="700">